==> haskell-tasty-golden-2.3.1.2-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-tasty-golden.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty-golden
version: 2.3.1.2
id: tasty-golden-2.3.1.2-9hiUcDWVQtGITLXK0fXTSD
key: tasty-golden-2.3.1.2-9hiUcDWVQtGITLXK0fXTSD
license: MIT
maintainer: Roman Cheplyaka <roma@ro-che.info>
homepage: https://github.com/feuerbach/tasty-golden
synopsis: Golden tests support for tasty
description:
    This package provides support for «golden testing».
    A golden test is an IO action that writes its result to a file.
    To pass the test, this output file should be identical to the corresponding
    «golden» file, which contains the correct result for the test.
    To get started with golden testing and this library, see
    <https://ro-che.info/articles/2017-12-04-golden-tests Introduction to golden testing>.
category: Testing
author: Roman Cheplyaka
exposed: True
indefinite: False
exposed-modules:
    Test.Tasty.Golden Test.Tasty.Golden.Advanced
    Test.Tasty.Golden.Manage
hidden-modules: Test.Tasty.Golden.Internal
abi: e3a7fa78beea9c36372b879377de9d2b
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/tasty-golden-2.3.1.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/tasty-golden-2.3.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/tasty-golden-2.3.1.2
hs-libraries: HStasty-golden-2.3.1.2-9hiUcDWVQtGITLXK0fXTSD
depends:
    base-4.10.1.0 tasty-0.12.0.1-BrMOfOJpa4GCtpWs3V78qY
    bytestring-0.10.8.2 process-1.6.1.0
    mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH
    optparse-applicative-0.14.0.0-2ZfllZxq2ruLdMUolNlkAF
    filepath-1.4.1.2 temporary-1.2.1.1-2QgeQJQfCPf69oxJVZZ5cG
    tagged-0.8.5-BP06XmR1GLaIsvsOKwGst2 deepseq-1.4.3.0
    containers-0.5.10.2 directory-1.3.0.2
    async-2.1.1.1-8ROwjo1yVqvF3cWHtq6DEd
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             tasty-0.12.0.1-BrMOfOJpa4GCtpWs3V78qY=735f36c898ebe4cd62d386315e2e8f2d
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             process-1.6.1.0=e78440f24fd9cc3300a1da2a92a47757
             mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH=a1f89647d7228db4bf59b7aaec52e888
             optparse-applicative-0.14.0.0-2ZfllZxq2ruLdMUolNlkAF=2737f341ca406f3c57e161b5a93d63ac
             filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
             temporary-1.2.1.1-2QgeQJQfCPf69oxJVZZ5cG=ab0f4b4f4a78e7c697cf1bced8c58e9c
             tagged-0.8.5-BP06XmR1GLaIsvsOKwGst2=b5d07becd47ba21e20b584b61ad0f06d
             deepseq-1.4.3.0=e843b5d736cc095915bf2399fddf152e
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             directory-1.3.0.2=7b913664ccd770192b307d7c4c6817cc
             async-2.1.1.1-8ROwjo1yVqvF3cWHtq6DEd=987aeec331bd3d9d85b408736a8805c6
haddock-interfaces: /usr/share/doc/haskell-tasty-golden/html/tasty-golden.haddock
haddock-html: /usr/share/doc/haskell-tasty-golden/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-golden-2.3.1.3-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-tasty-golden.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty-golden
version: 2.3.1.3
id: tasty-golden-2.3.1.3-HwZVd6YdcQ81IEFxRWFFau
key: tasty-golden-2.3.1.3-HwZVd6YdcQ81IEFxRWFFau
license: MIT
maintainer: Roman Cheplyaka <roma@ro-che.info>
homepage: https://github.com/feuerbach/tasty-golden
synopsis: Golden tests support for tasty
description:
    This package provides support for «golden testing».
    A golden test is an IO action that writes its result to a file.
    To pass the test, this output file should be identical to the corresponding
    «golden» file, which contains the correct result for the test.
    To get started with golden testing and this library, see
    <https://ro-che.info/articles/2017-12-04-golden-tests Introduction to golden testing>.
category: Testing
author: Roman Cheplyaka
exposed: True
indefinite: False
exposed-modules:
    Test.Tasty.Golden Test.Tasty.Golden.Advanced
    Test.Tasty.Golden.Manage
hidden-modules: Test.Tasty.Golden.Internal
abi: c9119ddef847a5178632e933014cad43
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/tasty-golden-2.3.1.3
library-dirs: /usr/lib/ghc-8.2.2/site-local/tasty-golden-2.3.1.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/tasty-golden-2.3.1.3
hs-libraries: HStasty-golden-2.3.1.3-HwZVd6YdcQ81IEFxRWFFau
depends:
    base-4.10.1.0 tasty-1.0.1-AWWNaFTEpDABJ6I60QHIFP
    bytestring-0.10.8.2 process-1.6.1.0
    mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH
    optparse-applicative-0.14.0.0-2ZfllZxq2ruLdMUolNlkAF
    filepath-1.4.1.2 temporary-1.2.1.1-2QgeQJQfCPf69oxJVZZ5cG
    tagged-0.8.5-BP06XmR1GLaIsvsOKwGst2 deepseq-1.4.3.0
    containers-0.5.10.2 directory-1.3.0.2
    async-2.1.1.1-8ROwjo1yVqvF3cWHtq6DEd
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             tasty-1.0.1-AWWNaFTEpDABJ6I60QHIFP=676bfe39e5968a7e880bebc46f35c0bf
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             process-1.6.1.0=e78440f24fd9cc3300a1da2a92a47757
             mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH=a1f89647d7228db4bf59b7aaec52e888
             optparse-applicative-0.14.0.0-2ZfllZxq2ruLdMUolNlkAF=2737f341ca406f3c57e161b5a93d63ac
             filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
             temporary-1.2.1.1-2QgeQJQfCPf69oxJVZZ5cG=ab0f4b4f4a78e7c697cf1bced8c58e9c
             tagged-0.8.5-BP06XmR1GLaIsvsOKwGst2=b5d07becd47ba21e20b584b61ad0f06d
             deepseq-1.4.3.0=e843b5d736cc095915bf2399fddf152e
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             directory-1.3.0.2=7b913664ccd770192b307d7c4c6817cc
             async-2.1.1.1-8ROwjo1yVqvF3cWHtq6DEd=987aeec331bd3d9d85b408736a8805c6
haddock-interfaces: /usr/share/doc/haskell-tasty-golden/html/tasty-golden.haddock
haddock-html: /usr/share/doc/haskell-tasty-golden/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
